@@ -1,7 +1,7 @@
 /* -*-c-*- ---------------- mixgtk_config.h :
  * Configuration functions declarations.
  * ------------------------------------------------------------------
- *  Last change: Time-stamp: <2001-04-29 12:07:11 jao>
+ *  $Id: mixgtk_config.h,v 1.5 2001/09/18 22:50:30 jao Exp $
  * ------------------------------------------------------------------
  * Copyright (C) 2001 Free Software Foundation, Inc.
  *  
@@ -51,6 +51,10 @@ mixgtk_config_update (const gchar *key, const gchar *value);
 extern const gchar *
 mixgtk_config_get (const gchar *key);
 
+/* remove config item */
+extern void
+mixgtk_config_remove (const gchar *key);
+
 /* save configuration */
 extern void
 mixgtk_config_save (void);
