@@ -561,7 +561,7 @@ void
 on_devdir_ok_clicked ()
 {
   const gchar *dirname = gtk_entry_get_text (devdir_entry_);
-  gchar *cmd = g_strconcat (mix_vm_command_to_string (MIX_CMD_DEVDIR),
+  gchar *cmd = g_strconcat (mix_vm_command_to_string (MIX_CMD_SDDIR),
 			    " ", dirname, NULL);
   gtk_widget_hide (devdir_dlg_);
   mixgtk_cmd_dispatcher_dispatch (cmd);
