@@ -33,10 +33,10 @@
 extern gboolean
 mixgtk_device_init (GtkNotebook *container, mix_vm_t *vm);
 
+/* change the output format of a device */
+extern void
+mixgtk_device_set_format (mix_device_type_t dev, gboolean dec);
 
-/* connect a new (file-based) device */
-extern gboolean
-mixgtk_device_connect (mix_device_type_t type, const gchar *name);
 
 #endif /* MIXGTK_DEVICE_H */
 
