@@ -1,7 +1,7 @@
 /* -*-c-*- -------------- mixgtk_fontsel.c :
  * Implementation of the functions declared in mixgtk_fontsel.h
  * ------------------------------------------------------------------
- *  Last change: Time-stamp: "2001-05-10 23:37:14 jao"
+ *  $Id: mixgtk_fontsel.c,v 1.14 2001/09/18 22:51:29 jao Exp $
  * ------------------------------------------------------------------
  * Copyright (C) 2001 Free Software Foundation, Inc.
  *  
@@ -62,6 +62,30 @@ static mixgtk_dialog_id_t dialog_ids_split_[] = {
   MIXGTK_DEVICES_DIALOG
 };
 
+static mixgtk_widget_id_t mixvm_children_[] = {
+  MIXGTK_WIDGET_rA,
+  MIXGTK_WIDGET_rX,
+  MIXGTK_WIDGET_rJ,
+  MIXGTK_WIDGET_rI1,
+  MIXGTK_WIDGET_rI2,
+  MIXGTK_WIDGET_rI3,
+  MIXGTK_WIDGET_rI4,
+  MIXGTK_WIDGET_rI5,
+  MIXGTK_WIDGET_rI6,
+  MIXGTK_WIDGET_CMP_L,
+  MIXGTK_WIDGET_CMP_E,
+  MIXGTK_WIDGET_CMP_G,
+  MIXGTK_WIDGET_OVER,
+  MIXGTK_WIDGET_CELLS,
+  MIXGTK_WIDGET_LAPTIME,
+  MIXGTK_WIDGET_PROGTIME,
+  MIXGTK_WIDGET_UPTIME,
+  MIXGTK_WIDGET_LOC
+};
+
+static const int CHILDREN_NO_ =
+(sizeof (mixvm_children_) / sizeof (mixvm_children_[0]));
+
 static mixgtk_dialog_id_t *dialog_ids_ = NULL;
 
 static const gchar *keys_[] = {
@@ -69,6 +93,7 @@ static const gchar *keys_[] = {
 };
 
 
+
 #define WIDGET_NO_  (sizeof (widget_ids_) / sizeof (widget_ids_[0]))
 
 static winfo infos_[WIDGET_NO_];
@@ -114,16 +139,17 @@ mixgtk_fontsel_load_defaults (void)
       infos_[i].widget =
 	mixgtk_widget_factory_get (dialog_ids_[i], widget_ids_[i]);
       g_assert (infos_[i].widget != NULL);
+      if (infos_[i].style) gtk_style_unref (infos_[i].style);
       infos_[i].style = gtk_style_copy
 	(gtk_widget_get_style (infos_[i].widget));
       gtk_widget_set_style (infos_[i].widget, infos_[i].style);
       if (widget_ids_[i] == MIXGTK_WIDGET_MIXVM)
 	{
 	  int k;
-	  for (k = MIXGTK_WIDGET_rA; k <= MIXGTK_WIDGET_UPTIME; ++k)
-	    gtk_widget_set_style
-	      (mixgtk_widget_factory_get (MIXGTK_MIXVM_DIALOG, k),
-	       infos_[i].style);
+	  for (k = 0; k < CHILDREN_NO_; ++k)
+	    gtk_widget_set_style (mixgtk_widget_factory_get
+				  (MIXGTK_MIXVM_DIALOG, mixvm_children_[k]),
+				  infos_[i].style);
 	}
       infos_[i].key = keys_[i];
       g_hash_table_insert (winfo_, GINT_TO_POINTER (widget_ids_[i]),
@@ -154,12 +180,16 @@ mixgtk_fontsel_set (mixgtk_widget_id_t widget, const gchar *font)
 	  if (widget == MIXGTK_WIDGET_MIXVM)
 	    {
 	      int k;
-	      for (k = MIXGTK_WIDGET_rA; k <= MIXGTK_WIDGET_UPTIME; ++k)
+	      for (k = 0; k < CHILDREN_NO_; ++k)
 		gtk_widget_draw
-		  (mixgtk_widget_factory_get (MIXGTK_MIXVM_DIALOG, k), NULL);
+		  (mixgtk_widget_factory_get (MIXGTK_MIXVM_DIALOG,
+					      mixvm_children_[k]),
+		   NULL);
 	    }
+	  mixgtk_config_update (w->key, w->font);
 	}
-      mixgtk_config_update (w->key, w->font);
+      else
+	mixgtk_config_remove (w->key);
     }
 
 }
@@ -208,9 +238,10 @@ on_devices_font_activate (void)
 void
 on_fontsel_apply_clicked (void)
 {
-  const gchar * name = gtk_font_selection_dialog_get_font_name
+  gchar * name = gtk_font_selection_dialog_get_font_name
     (GTK_FONT_SELECTION_DIALOG (fontsel_dialog_));
   mixgtk_fontsel_set (widget_, name);
+  g_free (name);
 }
 
 void
