@@ -42,6 +42,13 @@ static GtkWidget *childs_[SIZE_];
 static input_callback_t callback_;
 static gpointer data_;
 
+/* init */
+void
+mixgtk_input_init (void)
+{
+  dialog_ = NULL;
+}
+
 static void
 init_dialog_ (void)
 {
