@@ -1,7 +1,9 @@
 /* -*-c-*- -------------- mix.c :
  * Implementation of the functions declared in mix.h
  * ------------------------------------------------------------------
- * Copyright (C) 2000 Free Software Foundation, Inc.
+ *  $Id: mix.c,v 1.4 2001/09/28 23:10:45 jao Exp $
+ * ------------------------------------------------------------------
+ * Copyright (C) 2000, 2001 Free Software Foundation, Inc.
  *  
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -53,18 +55,18 @@ mix_release_lib (void)
 }
 
 const char *MIX_GPL_LICENSE = 
-"Copyright (C) 2000, 2001 Free Software Foundation, Inc.\n" 
-"GNU MDK is free software; you can redistribute it and/or modify\n"
-"it under the terms of the GNU General Public License as published by\n"
-"the Free Software Foundation; either version 2 of the License, or\n"
-"(at your option) any later version.\n"
-"GNU MDK is distributed in the hope that it will be useful,\n"
-"but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
-"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
-"GNU General Public License for more details.\n"
-"You should have received a copy of the GNU General Public License\n"
-"along with this program; if not, write to the Free Software\n"
-"Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.\n";
+"Copyright (C) 2001 Free Software Foundation, Inc.\n"
+"There is NO warranty.  You may redistribute this software\n"
+"under the terms of the GNU General Public License.\n"
+"For more information about these matters, see the files named COPYING.\n";
+
+void
+mix_print_license (const gchar *program)
+{
+  fprintf (stderr, _("%s (GNU MDK %s)\n\n"), 
+	   program, VERSION);
+  fprintf (stderr, MIX_GPL_LICENSE);
+}
 
 /* check dir, and create it if it doesn't exist */
 gboolean
