@@ -110,7 +110,7 @@ mix_io_write_word_array (mix_iochannel_t *ioc, const mix_word_t *w,
 {
   g_return_val_if_fail (ioc != NULL, FALSE);
   g_return_val_if_fail (w != NULL, FALSE);
-  return write_data_ (ioc, &w, s);
+  return write_data_ (ioc, w, s);
 }
 
 mix_word_t
@@ -143,7 +143,7 @@ mix_io_write_short_array (mix_iochannel_t *ioc, const mix_short_t *w,
 {
   g_return_val_if_fail (ioc != NULL, FALSE);
   g_return_val_if_fail (w != NULL, FALSE);
-  return write_data_ (ioc, &w, s);
+  return write_data_ (ioc, w, s);
 }
 
 mix_short_t
