@@ -1,7 +1,9 @@
 /* -*-c-*- -------------- mixvm.c :
  * Main function for mixvm, the mix vm simulator
  * ------------------------------------------------------------------
- * Copyright (C) 2000 Free Software Foundation, Inc.
+ *  $Id: mixvm.c,v 1.6 2001/09/28 23:10:45 jao Exp $
+ * ------------------------------------------------------------------
+ * Copyright (C) 2000, 2001 Free Software Foundation, Inc.
  *  
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,7 +37,8 @@
 #endif /* HAVE_GETOPT_LONG */
 
 extern void
-mix_vmloop (const gchar *code_file, gboolean use_emacs);
+mix_vmloop (int argc, char *argv[], gboolean initfile,
+	    const gchar *code_file, gboolean use_emacs);
 
 extern void
 mix_vmrun (const gchar *code_file, gboolean dump);
@@ -47,6 +50,7 @@ enum {
   RUN_OPT = 'r',
   DUMP_OPT = 'd',
   EMACS_OPT = 'e',	/* used by mixvm-gud only */
+  NOINIT_OPT = 'q'
 };
 
 static const char *options_ = "vhurd"; /* no short opt for --emacs */
@@ -60,11 +64,12 @@ static struct option long_options_[] =
   {"dump", no_argument, 0, DUMP_OPT},
   /* pek: yo! */
   {"emacs", no_argument, 0, EMACS_OPT},
+  {"noinit", no_argument, 0, NOINIT_OPT},
   {0, 0, 0, 0}
 };
 
 static const gchar *USAGE_ = 
-N_("Usage: %s [-vhurd] [--version] [--help] [--usage] [--run] [--dump] [MIX_FILE]\n");
+N_("Usage: %s [-vhurdq] [--version] [--help] [--noinit] [--usage] [--run] [--dump] [MIX_FILE]\n");
 
 int
 main (int argc, char **argv)
@@ -75,6 +80,7 @@ main (int argc, char **argv)
   gboolean run = FALSE;
   gboolean dump = FALSE;
   gboolean emacs = FALSE;
+  gboolean initfile = TRUE;
       
   setlocale (LC_ALL, "");
   bindtextdomain (PACKAGE, LOCALEDIR);
@@ -94,9 +100,7 @@ main (int argc, char **argv)
 	  fprintf (stderr, _(USAGE_), prog_name);
 	  return EXIT_SUCCESS;
      	case VER_OPT:
-	  fprintf (stderr, _("%s %s, MIX Virtual Machine.\n"), 
-		   prog_name, VERSION);
-	  fprintf (stderr, MIX_GPL_LICENSE);
+	  mix_print_license ("mixvm, MIX virtual machine");
 	  return EXIT_SUCCESS;
 	case RUN_OPT:
 	  in = optarg;
@@ -112,6 +116,9 @@ main (int argc, char **argv)
 	case EMACS_OPT:
 	  emacs = TRUE;
 	  break;
+	case NOINIT_OPT:
+	  initfile = FALSE;
+	  break;
 	default:
 	  g_assert_not_reached ();
 	}
@@ -128,7 +135,7 @@ main (int argc, char **argv)
   mix_init_lib ();
   
   if (run) mix_vmrun(in, dump);
-  else mix_vmloop (in, emacs);
+  else mix_vmloop (argc, argv, initfile, in, emacs);
 
   mix_release_lib ();
   
