@@ -24,8 +24,9 @@
 #define MIXVM_COMMAND_H
 
 #include <mixlib/mix_config.h>
+#include <mixlib/mix_vm_command.h>
 
-extern void
+extern mix_vm_cmd_dispatcher_t *
 mixvm_cmd_init (mix_config_t *config, char *arg, gboolean use_emacs);
 
 extern gboolean
